summaryrefslogtreecommitdiffstats
path: root/cmake
diff options
context:
space:
mode:
authorKai Köhne <kai.koehne@qt.io>2021-11-16 12:19:06 +0100
committerKai Köhne <kai.koehne@qt.io>2021-11-30 16:32:10 +0100
commit6c10546a4b6e5a055358515b3606e22fac34b142 (patch)
tree801a0ab55e23082b0b650fad8fe0e21b939f8eb5 /cmake
parentbcac7d94334d178dcf55930f4cef972a3eb749bd (diff)
Enable warnings-are-errors for Visual Studio 2022
Change-Id: Id0b143f668f69481f6037f94aedbfd2e87331497 Reviewed-by: Oliver Wolff <oliver.wolff@qt.io>
Diffstat (limited to 'cmake')
-rw-r--r--cmake/QtInternalTargets.cmake4
1 files changed, 2 insertions, 2 deletions
diff --git a/cmake/QtInternalTargets.cmake b/cmake/QtInternalTargets.cmake
index 7a0d8cd1b7..aee33c5dde 100644
--- a/cmake/QtInternalTargets.cmake
+++ b/cmake/QtInternalTargets.cmake
@@ -49,8 +49,8 @@ function(qt_internal_set_warnings_are_errors_flags target)
endif()
elseif ("${CMAKE_CXX_COMPILER_ID}" STREQUAL "MSVC")
# Only enable for versions of MSVC that are known to work
- # 1929 is Visual Studio 2019 version 16.0
- if(MSVC_VERSION LESS_EQUAL 1929)
+ # 1939 is Visual Studio 2022 version 17.0
+ if(MSVC_VERSION LESS_EQUAL 1939)
list(APPEND flags /WX)
endif()
endif()